from pyiso20022.camt.camt_052_001_12.camt_052_001_12 import (
    AccountIdentification4Choice,
    AccountInterest4,
    AccountReport33,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAnd13DecimalAmount,
    ActiveOrHistoricCurrencyAndAmount,
    ActiveOrHistoricCurrencyAndAmountRange2,
    AddressType2Code,
    AddressType3Choice,
    AmountAndCurrencyExchange4,
    AmountAndCurrencyExchangeDetails5,
    AmountAndCurrencyExchangeDetails6,
    AmountAndDirection35,
    AmountRangeBoundary1,
    AttendanceContext1Code,
    AuthenticationEntity1Code,
    AuthenticationMethod1Code,
    BalanceSubType1Choice,
    BalanceType10Choice,
    BalanceType13,
    BankToCustomerAccountReportV12,
    BankTransactionCodeStructure4,
    BankTransactionCodeStructure5,
    BankTransactionCodeStructure6,
    BatchInformation2,
    BranchAndFinancialInstitutionIdentification8,
    BranchData5,
    CardAggregated2,
    CardDataReading1Code,
    CardEntry5,
    CardholderAuthentication2,
    CardholderVerificationCapability1Code,
    CardIndividualTransaction2,
    CardPaymentServiceType2Code,
    CardSecurityInformation1,
    CardSequenceNumberRange1,
    CardTransaction3Choice,
    CardTransaction18,
    CashAccount40,
    CashAccount43,
    CashAccountType2Choice,
    CashAvailability1,
    CashAvailabilityDate1Choice,
    CashBalance8,
    CashDeposit1,
    CategoryPurpose1Choice,
    ChargeBearerType1Code,
    Charges15,
    ChargesRecord8,
    ChargeType3Choice,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    Contact13,
    CopyDuplicate1Code,
    CorporateAction9,
    CreditDebitCode,
    CreditLine3,
    CreditLineType1Choice,
    CreditorReferenceInformation3,
    CreditorReferenceType2Choice,
    CreditorReferenceType3,
    Cscmanagement1Code,
    CurrencyExchange24,
    DateAndDateTime2Choice,
    DateAndPlaceOfBirth1,
    DateAndType1,
    DateOrDateTimePeriod1Choice,
    DatePeriod2,
    DateTimePeriod1,
    DateType2Choice,
    DisplayCapabilities1,
    Document,
    DocumentAdjustment1,
    DocumentAmount1,
    DocumentAmountType1Choice,
    DocumentLineIdentification1,
    DocumentLineInformation2,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType1,
    DocumentType2Choice,
    EntryDetails13,
    EntryStatus1Choice,
    EntryTransaction14,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification23,
    FinancialInstrumentQuantity1Choice,
    FromToAmountRange1,
    Garnishment4,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification1,
    GenericIdentification3,
    GenericIdentification30,
    GenericIdentification32,
    GenericOrganisationIdentification3,
    GenericPersonIdentification2,
    GroupHeader116,
    IdentificationSource3Choice,
    ImpliedCurrencyAmountRange1Choice,
    InterestRecord2,
    InterestType1Choice,
    InterestType1Code,
    LocalInstrument2Choice,
    MessageIdentification2,
    NameAndAddress18,
    NamePrefix2Code,
    NumberAndSumOfTransactions1,
    NumberAndSumOfTransactions4,
    OnLineCapability1Code,
    OrganisationIdentification39,
    OrganisationIdentificationSchemeName1Choice,
    OriginalAndCurrentQuantities1,
    OriginalBusinessQuery1,
    OtherContact1,
    OtherIdentification1,
    Pagination1,
    Party50Choice,
    Party52Choice,
    PartyIdentification272,
    PartyType3Code,
    PartyType4Code,
    PaymentCard4,
    PaymentContext3,
    PaymentReturnReason8,
    PaymentTypeInformation27,
    PersonIdentification18,
    PersonIdentificationSchemeName1Choice,
    PlainCardData1,
    PoicomponentType1Code,
    PointOfInteraction1,
    PointOfInteractionCapabilities1,
    PointOfInteractionComponent1,
    PostalAddress27,
    PreferredContactMethod2Code,
    Price7,
    PriceRateOrAmount3Choice,
    PriceValueType1Code,
    Priority2Code,
    Product2,
    ProprietaryAgent5,
    ProprietaryBankTransactionCodeStructure1,
    ProprietaryDate3,
    ProprietaryParty6,
    ProprietaryPrice2,
    ProprietaryQuantity1,
    ProprietaryReference1,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    Purpose2Choice,
    Rate4,
    RateType4Choice,
    ReferredDocumentInformation8,
    RemittanceAmount4,
    RemittanceInformation22,
    RemittanceLocation8,
    RemittanceLocationData2,
    RemittanceLocationMethod2Code,
    ReportEntry14,
    ReportingSource1Choice,
    ReturnReason5Choice,
    SecuritiesAccount19,
    SecurityIdentification19,
    SequenceRange1,
    SequenceRange1Choice,
    SequenceType3Code,
    ServiceLevel8Choice,
    StructuredRemittanceInformation18,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount3,
    TaxAuthorisation1,
    TaxCharges2,
    TaxData1,
    TaxParty1,
    TaxParty2,
    TaxPeriod3,
    TaxRecord3,
    TaxRecordDetails3,
    TaxRecordPeriod1Code,
    TechnicalInputChannel1Choice,
    TotalsPerBankTransactionCode5,
    TotalTransactions6,
    TrackData1,
    TransactionAgents6,
    TransactionChannel1Code,
    TransactionDates3,
    TransactionEnvironment1Code,
    TransactionIdentifier1,
    TransactionInterest4,
    TransactionParties12,
    TransactionPrice4Choice,
    TransactionQuantities3Choice,
    TransactionReferences6,
    UnitOfMeasure1Code,
    UserInterface2Code,
    YieldedOrValueType1Choice,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountInterest4",
    "AccountReport33",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAnd13DecimalAmount",
    "ActiveOrHistoricCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAndAmountRange2",
    "AddressType2Code",
    "AddressType3Choice",
    "AmountAndCurrencyExchange4",
    "AmountAndCurrencyExchangeDetails5",
    "AmountAndCurrencyExchangeDetails6",
    "AmountAndDirection35",
    "AmountRangeBoundary1",
    "AttendanceContext1Code",
    "AuthenticationEntity1Code",
    "AuthenticationMethod1Code",
    "BalanceSubType1Choice",
    "BalanceType10Choice",
    "BalanceType13",
    "BankToCustomerAccountReportV12",
    "BankTransactionCodeStructure4",
    "BankTransactionCodeStructure5",
    "BankTransactionCodeStructure6",
    "BatchInformation2",
    "BranchAndFinancialInstitutionIdentification8",
    "BranchData5",
    "Cscmanagement1Code",
    "CardAggregated2",
    "CardDataReading1Code",
    "CardEntry5",
    "CardIndividualTransaction2",
    "CardPaymentServiceType2Code",
    "CardSecurityInformation1",
    "CardSequenceNumberRange1",
    "CardTransaction18",
    "CardTransaction3Choice",
    "CardholderAuthentication2",
    "CardholderVerificationCapability1Code",
    "CashAccount40",
    "CashAccount43",
    "CashAccountType2Choice",
    "CashAvailability1",
    "CashAvailabilityDate1Choice",
    "CashBalance8",
    "CashDeposit1",
    "CategoryPurpose1Choice",
    "ChargeBearerType1Code",
    "ChargeType3Choice",
    "Charges15",
    "ChargesRecord8",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "Contact13",
    "CopyDuplicate1Code",
    "CorporateAction9",
    "CreditDebitCode",
    "CreditLine3",
    "CreditLineType1Choice",
    "CreditorReferenceInformation3",
    "CreditorReferenceType2Choice",
    "CreditorReferenceType3",
    "CurrencyExchange24",
    "DateAndDateTime2Choice",
    "DateAndPlaceOfBirth1",
    "DateAndType1",
    "DateOrDateTimePeriod1Choice",
    "DatePeriod2",
    "DateTimePeriod1",
    "DateType2Choice",
    "DisplayCapabilities1",
    "Document",
    "DocumentAdjustment1",
    "DocumentAmount1",
    "DocumentAmountType1Choice",
    "DocumentLineIdentification1",
    "DocumentLineInformation2",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType1",
    "DocumentType2Choice",
    "EntryDetails13",
    "EntryStatus1Choice",
    "EntryTransaction14",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification23",
    "FinancialInstrumentQuantity1Choice",
    "FromToAmountRange1",
    "Garnishment4",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification1",
    "GenericIdentification3",
    "GenericIdentification30",
    "GenericIdentification32",
    "GenericOrganisationIdentification3",
    "GenericPersonIdentification2",
    "GroupHeader116",
    "IdentificationSource3Choice",
    "ImpliedCurrencyAmountRange1Choice",
    "InterestRecord2",
    "InterestType1Choice",
    "InterestType1Code",
    "LocalInstrument2Choice",
    "MessageIdentification2",
    "NameAndAddress18",
    "NamePrefix2Code",
    "NumberAndSumOfTransactions1",
    "NumberAndSumOfTransactions4",
    "OnLineCapability1Code",
    "OrganisationIdentification39",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalAndCurrentQuantities1",
    "OriginalBusinessQuery1",
    "OtherContact1",
    "OtherIdentification1",
    "PoicomponentType1Code",
    "Pagination1",
    "Party50Choice",
    "Party52Choice",
    "PartyIdentification272",
    "PartyType3Code",
    "PartyType4Code",
    "PaymentCard4",
    "PaymentContext3",
    "PaymentReturnReason8",
    "PaymentTypeInformation27",
    "PersonIdentification18",
    "PersonIdentificationSchemeName1Choice",
    "PlainCardData1",
    "PointOfInteraction1",
    "PointOfInteractionCapabilities1",
    "PointOfInteractionComponent1",
    "PostalAddress27",
    "PreferredContactMethod2Code",
    "Price7",
    "PriceRateOrAmount3Choice",
    "PriceValueType1Code",
    "Priority2Code",
    "Product2",
    "ProprietaryAgent5",
    "ProprietaryBankTransactionCodeStructure1",
    "ProprietaryDate3",
    "ProprietaryParty6",
    "ProprietaryPrice2",
    "ProprietaryQuantity1",
    "ProprietaryReference1",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "Purpose2Choice",
    "Rate4",
    "RateType4Choice",
    "ReferredDocumentInformation8",
    "RemittanceAmount4",
    "RemittanceInformation22",
    "RemittanceLocation8",
    "RemittanceLocationData2",
    "RemittanceLocationMethod2Code",
    "ReportEntry14",
    "ReportingSource1Choice",
    "ReturnReason5Choice",
    "SecuritiesAccount19",
    "SecurityIdentification19",
    "SequenceRange1",
    "SequenceRange1Choice",
    "SequenceType3Code",
    "ServiceLevel8Choice",
    "StructuredRemittanceInformation18",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount3",
    "TaxAuthorisation1",
    "TaxCharges2",
    "TaxData1",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod3",
    "TaxRecord3",
    "TaxRecordDetails3",
    "TaxRecordPeriod1Code",
    "TechnicalInputChannel1Choice",
    "TotalTransactions6",
    "TotalsPerBankTransactionCode5",
    "TrackData1",
    "TransactionAgents6",
    "TransactionChannel1Code",
    "TransactionDates3",
    "TransactionEnvironment1Code",
    "TransactionIdentifier1",
    "TransactionInterest4",
    "TransactionParties12",
    "TransactionPrice4Choice",
    "TransactionQuantities3Choice",
    "TransactionReferences6",
    "UnitOfMeasure1Code",
    "UserInterface2Code",
    "YieldedOrValueType1Choice",
]



from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional

from xsdata.models.datatype import XmlDate, XmlDateTime, XmlTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02"


@dataclass
class AccountSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ActiveCurrencyAndAmount:
    value: Optional[Decimal] = field(
        default=None,
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        },
    )


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


@dataclass
class CashAccountType2Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ClearingSystemIdentification3Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 3,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


class CreditDebitCode(Enum):
    CRDT = "CRDT"
    DBIT = "DBIT"


@dataclass
class DateAndPlaceOfBirth1:
    birth_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "BirthDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )
    prvc_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "PrvcOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )
    city_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "CityOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtryOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        },
    )


@dataclass
class GenericIdentification30:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "pattern": r"[a-zA-Z0-9]{4}",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


class NamePrefix2Code(Enum):
    DOCT = "DOCT"
    MADM = "MADM"
    MISS = "MISS"
    MIST = "MIST"
    MIKS = "MIKS"


@dataclass
class OrganisationIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class OtherContact1:
    chanl_tp: Optional[str] = field(
        default=None,
        metadata={
            "name": "ChanlTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 4,
        },
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 128,
        },
    )


@dataclass
class PersonIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


class PreferredContactMethod2Code(Enum):
    MAIL = "MAIL"
    FAXX = "FAXX"
    LETT = "LETT"
    CELL = "CELL"
    ONLI = "ONLI"
    PHON = "PHON"


class Priority3Code(Enum):
    URGT = "URGT"
    HIGH = "HIGH"
    NORM = "NORM"


@dataclass
class ProxyAccountType1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


class SettlementMethod2Code(Enum):
    INDA = "INDA"
    INGA = "INGA"
    CLRG = "CLRG"


@dataclass
class SettlementTimeRequest2:
    clstm: Optional[XmlTime] = field(
        default=None,
        metadata={
            "name": "CLSTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    till_tm: Optional[XmlTime] = field(
        default=None,
        metadata={
            "name": "TillTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    fr_tm: Optional[XmlTime] = field(
        default=None,
        metadata={
            "name": "FrTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    rjct_tm: Optional[XmlTime] = field(
        default=None,
        metadata={
            "name": "RjctTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class SupplementaryDataEnvelope1:
    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass
class AddressType3Choice:
    cd: Optional[AddressType2Code] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    prtry: Optional[GenericIdentification30] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class AmountAndDirection5:
    amt: Optional[ActiveCurrencyAndAmount] = field(
        default=None,
        metadata={
            "name": "Amt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )
    cdt_dbt: Optional[CreditDebitCode] = field(
        default=None,
        metadata={
            "name": "CdtDbt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class Contact13:
    nm_prfx: Optional[NamePrefix2Code] = field(
        default=None,
        metadata={
            "name": "NmPrfx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    phne_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "PhneNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    mob_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "MobNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    fax_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "FaxNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    urladr: Optional[str] = field(
        default=None,
        metadata={
            "name": "URLAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 2048,
        },
    )
    email_adr: Optional[str] = field(
        default=None,
        metadata={
            "name": "EmailAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 256,
        },
    )
    email_purp: Optional[str] = field(
        default=None,
        metadata={
            "name": "EmailPurp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )
    job_titl: Optional[str] = field(
        default=None,
        metadata={
            "name": "JobTitl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )
    rspnsblty: Optional[str] = field(
        default=None,
        metadata={
            "name": "Rspnsblty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )
    dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "Dept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 70,
        },
    )
    othr: List[OtherContact1] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    prefrd_mtd: Optional[PreferredContactMethod2Code] = field(
        default=None,
        metadata={
            "name": "PrefrdMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class GenericAccountIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 34,
        },
    )
    schme_nm: Optional[AccountSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericOrganisationIdentification3:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 256,
        },
    )
    schme_nm: Optional[OrganisationIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericPersonIdentification2:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 256,
        },
    )
    schme_nm: Optional[PersonIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ProxyAccountIdentification1:
    tp: Optional[ProxyAccountType1Choice] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 2048,
        },
    )


@dataclass
class SupplementaryData1:
    plc_and_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: Optional[SupplementaryDataEnvelope1] = field(
        default=None,
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )


@dataclass
class AccountIdentification4Choice:
    iban: Optional[str] = field(
        default=None,
        metadata={
            "name": "IBAN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"[A-Z]{2,2}[0-9]{2,2}[a-zA-Z0-9]{1,30}",
        },
    )
    othr: Optional[GenericAccountIdentification1] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class OrganisationIdentification39:
    any_bic: Optional[str] = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"[A-Z0-9]{4,4}[A-Z]{2,2}[A-Z0-9]{2,2}([A-Z0-9]{3,3}){0,1}",
        },
    )
    lei: Optional[str] = field(
        default=None,
        metadata={
            "name": "LEI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"[A-Z0-9]{18,18}[0-9]{2,2}",
        },
    )
    othr: List[GenericOrganisationIdentification3] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class PersonIdentification18:
    dt_and_plc_of_birth: Optional[DateAndPlaceOfBirth1] = field(
        default=None,
        metadata={
            "name": "DtAndPlcOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    othr: List[GenericPersonIdentification2] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class PostalAddress27:
    adr_tp: Optional[AddressType3Choice] = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    care_of: Optional[str] = field(
        default=None,
        metadata={
            "name": "CareOf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "Dept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 70,
        },
    )
    sub_dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "SubDept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    bldg_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 16,
        },
    )
    bldg_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    flr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Flr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 70,
        },
    )
    unit_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "UnitNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_bx: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstBx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 16,
        },
    )
    room: Optional[str] = field(
        default=None,
        metadata={
            "name": "Room",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 70,
        },
    )
    pst_cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    twn_lctn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnLctnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    dstrct_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "DstrctNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    ctry_sub_dvsn: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    adr_line: List[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "max_occurs": 7,
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class CashAccount40:
    id: Optional[AccountIdentification4Choice] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    tp: Optional[CashAccountType2Choice] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"[A-Z]{3,3}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 70,
        },
    )
    prxy: Optional[ProxyAccountIdentification1] = field(
        default=None,
        metadata={
            "name": "Prxy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class Party52Choice:
    org_id: Optional[OrganisationIdentification39] = field(
        default=None,
        metadata={
            "name": "OrgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    prvt_id: Optional[PersonIdentification18] = field(
        default=None,
        metadata={
            "name": "PrvtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class PartyIdentification272:
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress27] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    id: Optional[Party52Choice] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    ctry_of_res: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtryOfRes",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    ctct_dtls: Optional[Contact13] = field(
        default=None,
        metadata={
            "name": "CtctDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class SettlementInstruction14:
    sttlm_mtd: Optional[SettlementMethod2Code] = field(
        default=None,
        metadata={
            "name": "SttlmMtd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )
    sttlm_acct: Optional[CashAccount40] = field(
        default=None,
        metadata={
            "name": "SttlmAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    clr_sys: Optional[ClearingSystemIdentification3Choice] = field(
        default=None,
        metadata={
            "name": "ClrSys",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class GroupHeader104:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    cre_dt_tm: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )
    nb_of_sttlm_reqs: Optional[str] = field(
        default=None,
        metadata={
            "name": "NbOfSttlmReqs",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "pattern": r"[0-9]{1,15}",
        },
    )
    ctrl_sum: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "CtrlSum",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "total_digits": 18,
            "fraction_digits": 17,
        },
    )
    sttlm_inf: Optional[SettlementInstruction14] = field(
        default=None,
        metadata={
            "name": "SttlmInf",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class MovementRecord2:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    seq_nb: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "SeqNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "total_digits": 18,
            "fraction_digits": 0,
        },
    )
    amt: Optional[AmountAndDirection5] = field(
        default=None,
        metadata={
            "name": "Amt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )
    sttlm_agt: Optional[PartyIdentification272] = field(
        default=None,
        metadata={
            "name": "SttlmAgt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    sttlm_agt_acct: Optional[CashAccount40] = field(
        default=None,
        metadata={
            "name": "SttlmAgtAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    ptcpt: Optional[PartyIdentification272] = field(
        default=None,
        metadata={
            "name": "Ptcpt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    ptcpt_acct: Optional[CashAccount40] = field(
        default=None,
        metadata={
            "name": "PtcptAcct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    ref: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ref",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class MultilateralSettlementRequest3:
    instr_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "InstrId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    instr_prty: Optional[Priority3Code] = field(
        default=None,
        metadata={
            "name": "InstrPrty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    sttlm_tm_req: Optional[SettlementTimeRequest2] = field(
        default=None,
        metadata={
            "name": "SttlmTmReq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    sttlm_prty: Optional[Priority3Code] = field(
        default=None,
        metadata={
            "name": "SttlmPrty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )
    sttlm_cycl: Optional[str] = field(
        default=None,
        metadata={
            "name": "SttlmCycl",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_length": 1,
            "max_length": 35,
        },
    )
    nb_of_mvmnt_rcrds: Optional[Decimal] = field(
        default=None,
        metadata={
            "name": "NbOfMvmntRcrds",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "total_digits": 18,
            "fraction_digits": 0,
        },
    )
    mvmnt_rcrd: List[MovementRecord2] = field(
        default_factory=list,
        metadata={
            "name": "MvmntRcrd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_occurs": 2,
        },
    )


@dataclass
class MultilateralSettlementRequestV02:
    grp_hdr: Optional[GroupHeader104] = field(
        default=None,
        metadata={
            "name": "GrpHdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "required": True,
        },
    )
    sttlm_req: List[MultilateralSettlementRequest3] = field(
        default_factory=list,
        metadata={
            "name": "SttlmReq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
            "min_occurs": 1,
        },
    )
    splmtry_data: Optional[SupplementaryData1] = field(
        default=None,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02",
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:pacs.029.001.02"

    mul_sttlm_req: Optional[MultilateralSettlementRequestV02] = field(
        default=None,
        metadata={
            "name": "MulSttlmReq",
            "type": "Element",
            "required": True,
        },
    )



from pyiso20022.camt.camt_025_001_08.camt_025_001_08 import (
    AddressType2Code,
    AddressType3Choice,
    BranchAndFinancialInstitutionIdentification8,
    BranchData5,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    Contact13,
    DateAndPlaceOfBirth1,
    Document,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification23,
    GenericFinancialIdentification1,
    GenericIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification3,
    GenericPersonIdentification2,
    LongPaymentIdentification4,
    MessageHeader9,
    NamePrefix2Code,
    OrganisationIdentification39,
    OrganisationIdentificationSchemeName1Choice,
    OriginalMessageAndIssuer1,
    OtherContact1,
    Party52Choice,
    PartyIdentification272,
    PaymentIdentification8Choice,
    PaymentInstrument1Code,
    PaymentOrigin1Choice,
    PersonIdentification18,
    PersonIdentificationSchemeName1Choice,
    PostalAddress27,
    PreferredContactMethod2Code,
    QueueTransactionIdentification1,
    Receipt6,
    ReceiptV08,
    RequestHandling3,
    RequestStatus1Choice,
    RequestType4Choice,
    ShortPaymentIdentification4,
    StatusReason6Choice,
    StatusReasonInformation14,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
)

__all__ = [
    "AddressType2Code",
    "AddressType3Choice",
    "BranchAndFinancialInstitutionIdentification8",
    "BranchData5",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "Contact13",
    "DateAndPlaceOfBirth1",
    "Document",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification23",
    "GenericFinancialIdentification1",
    "GenericIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification3",
    "GenericPersonIdentification2",
    "LongPaymentIdentification4",
    "MessageHeader9",
    "NamePrefix2Code",
    "OrganisationIdentification39",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalMessageAndIssuer1",
    "OtherContact1",
    "Party52Choice",
    "PartyIdentification272",
    "PaymentIdentification8Choice",
    "PaymentInstrument1Code",
    "PaymentOrigin1Choice",
    "PersonIdentification18",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress27",
    "PreferredContactMethod2Code",
    "QueueTransactionIdentification1",
    "Receipt6",
    "ReceiptV08",
    "RequestHandling3",
    "RequestStatus1Choice",
    "RequestType4Choice",
    "ShortPaymentIdentification4",
    "StatusReason6Choice",
    "StatusReasonInformation14",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
]



from pyiso20022.pacs.pacs_004_001_07.pacs_004_001_07 import (
    AccountIdentification4Choice,
    AccountSchemeName1Choice,
    ActiveCurrencyAndAmount,
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    AmendmentInformationDetails11,
    AmountType4Choice,
    Authorisation1Choice,
    Authorisation1Code,
    BranchAndFinancialInstitutionIdentification5,
    BranchData2,
    CashAccount24,
    CashAccountType2Choice,
    CategoryPurpose1Choice,
    ChargeBearerType1Code,
    Charges2,
    ClearingChannel2Code,
    ClearingSystemIdentification2Choice,
    ClearingSystemIdentification3Choice,
    ClearingSystemMemberIdentification2,
    ContactDetails2,
    CreditDebitCode,
    CreditorReferenceInformation2,
    CreditorReferenceType1Choice,
    CreditorReferenceType2,
    DateAndDateTimeChoice,
    DateAndPlaceOfBirth,
    DatePeriodDetails,
    DiscountAmountAndType1,
    DiscountAmountType1Choice,
    Document,
    DocumentAdjustment1,
    DocumentLineIdentification1,
    DocumentLineInformation1,
    DocumentLineType1,
    DocumentLineType1Choice,
    DocumentType3Code,
    DocumentType6Code,
    EquivalentAmount2,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification8,
    Frequency6Code,
    Frequency36Choice,
    FrequencyAndMoment1,
    FrequencyPeriod1,
    Garnishment1,
    GarnishmentType1,
    GarnishmentType1Choice,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    GroupHeader72,
    LocalInstrument2Choice,
    MandateRelatedInformation11,
    MandateSetupReason1Choice,
    NamePrefix1Code,
    OrganisationIdentification8,
    OrganisationIdentificationSchemeName1Choice,
    OriginalGroupHeader2,
    OriginalGroupInformation3,
    OriginalTransactionReference24,
    Party11Choice,
    PartyIdentification43,
    PaymentMethod4Code,
    PaymentReturnReason1,
    PaymentReturnV07,
    PaymentTransaction76,
    PaymentTypeInformation25,
    PersonIdentification5,
    PersonIdentificationSchemeName1Choice,
    PostalAddress6,
    Priority2Code,
    Priority3Code,
    ReferredDocumentInformation7,
    ReferredDocumentType3Choice,
    ReferredDocumentType4,
    RemittanceAmount2,
    RemittanceAmount3,
    RemittanceInformation11,
    ReturnReason5Choice,
    SequenceType3Code,
    ServiceLevel8Choice,
    SettlementInstruction4,
    SettlementMethod1Code,
    StructuredRemittanceInformation13,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TaxAmount1,
    TaxAmountAndType1,
    TaxAmountType1Choice,
    TaxAuthorisation1,
    TaxInformation4,
    TaxParty1,
    TaxParty2,
    TaxPeriod1,
    TaxRecord1,
    TaxRecordDetails1,
    TaxRecordPeriod1Code,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountSchemeName1Choice",
    "ActiveCurrencyAndAmount",
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "AmendmentInformationDetails11",
    "AmountType4Choice",
    "Authorisation1Choice",
    "Authorisation1Code",
    "BranchAndFinancialInstitutionIdentification5",
    "BranchData2",
    "CashAccount24",
    "CashAccountType2Choice",
    "CategoryPurpose1Choice",
    "ChargeBearerType1Code",
    "Charges2",
    "ClearingChannel2Code",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemIdentification3Choice",
    "ClearingSystemMemberIdentification2",
    "ContactDetails2",
    "CreditDebitCode",
    "CreditorReferenceInformation2",
    "CreditorReferenceType1Choice",
    "CreditorReferenceType2",
    "DateAndDateTimeChoice",
    "DateAndPlaceOfBirth",
    "DatePeriodDetails",
    "DiscountAmountAndType1",
    "DiscountAmountType1Choice",
    "Document",
    "DocumentAdjustment1",
    "DocumentLineIdentification1",
    "DocumentLineInformation1",
    "DocumentLineType1",
    "DocumentLineType1Choice",
    "DocumentType3Code",
    "DocumentType6Code",
    "EquivalentAmount2",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification8",
    "Frequency36Choice",
    "Frequency6Code",
    "FrequencyAndMoment1",
    "FrequencyPeriod1",
    "Garnishment1",
    "GarnishmentType1",
    "GarnishmentType1Choice",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "GroupHeader72",
    "LocalInstrument2Choice",
    "MandateRelatedInformation11",
    "MandateSetupReason1Choice",
    "NamePrefix1Code",
    "OrganisationIdentification8",
    "OrganisationIdentificationSchemeName1Choice",
    "OriginalGroupHeader2",
    "OriginalGroupInformation3",
    "OriginalTransactionReference24",
    "Party11Choice",
    "PartyIdentification43",
    "PaymentMethod4Code",
    "PaymentReturnReason1",
    "PaymentReturnV07",
    "PaymentTransaction76",
    "PaymentTypeInformation25",
    "PersonIdentification5",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress6",
    "Priority2Code",
    "Priority3Code",
    "ReferredDocumentInformation7",
    "ReferredDocumentType3Choice",
    "ReferredDocumentType4",
    "RemittanceAmount2",
    "RemittanceAmount3",
    "RemittanceInformation11",
    "ReturnReason5Choice",
    "SequenceType3Code",
    "ServiceLevel8Choice",
    "SettlementInstruction4",
    "SettlementMethod1Code",
    "StructuredRemittanceInformation13",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TaxAmount1",
    "TaxAmountAndType1",
    "TaxAmountType1Choice",
    "TaxAuthorisation1",
    "TaxInformation4",
    "TaxParty1",
    "TaxParty2",
    "TaxPeriod1",
    "TaxRecord1",
    "TaxRecordDetails1",
    "TaxRecordPeriod1Code",
]



from dataclasses import dataclass, field
from decimal import Decimal
from enum import Enum
from typing import List, Optional

from xsdata.models.datatype import XmlDate, XmlDateTime, XmlTime

__NAMESPACE__ = "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04"


@dataclass
class AccountSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ActiveOrHistoricCurrencyAndAmount:
    value: Optional[Decimal] = field(
        default=None,
        metadata={
            "required": True,
            "min_inclusive": Decimal("0"),
            "total_digits": 18,
            "fraction_digits": 5,
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Attribute",
            "required": True,
            "pattern": r"[A-Z]{3,3}",
        },
    )


class AddressType2Code(Enum):
    ADDR = "ADDR"
    PBOX = "PBOX"
    HOME = "HOME"
    BIZZ = "BIZZ"
    MLTO = "MLTO"
    DLVY = "DLVY"


@dataclass
class BalanceSubType1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class BalanceType10Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class CashAccountType2Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ClearingSystemIdentification2Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 5,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


class CreditDebitCode(Enum):
    CRDT = "CRDT"
    DBIT = "DBIT"


@dataclass
class DateAndPlaceOfBirth1:
    birth_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "BirthDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    prvc_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "PrvcOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    city_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "CityOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_of_birth: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtryOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "pattern": r"[A-Z]{2,2}",
        },
    )


@dataclass
class DatePeriodDetails1:
    fr_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "FrDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    to_dt: Optional[XmlDate] = field(
        default=None,
        metadata={
            "name": "ToDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class EntryStatus1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class FinancialIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


class FloorLimitType1Code(Enum):
    CRED = "CRED"
    DEBT = "DEBT"
    BOTH = "BOTH"


class NamePrefix1Code(Enum):
    DOCT = "DOCT"
    MIST = "MIST"
    MISS = "MISS"
    MADM = "MADM"


@dataclass
class OrganisationIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class PersonIdentificationSchemeName1Choice:
    cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "Cd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 4,
        },
    )
    prtry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Prtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


class QueryType3Code(Enum):
    ALLL = "ALLL"
    CHNG = "CHNG"
    MODF = "MODF"


@dataclass
class SequenceRange1:
    fr_seq: Optional[str] = field(
        default=None,
        metadata={
            "name": "FrSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    to_seq: Optional[str] = field(
        default=None,
        metadata={
            "name": "ToSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class SupplementaryDataEnvelope1:
    any_element: Optional[object] = field(
        default=None,
        metadata={
            "type": "Wildcard",
            "namespace": "##any",
        },
    )


@dataclass
class TimePeriodDetails1:
    fr_tm: Optional[XmlTime] = field(
        default=None,
        metadata={
            "name": "FrTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    to_tm: Optional[XmlTime] = field(
        default=None,
        metadata={
            "name": "ToTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class BalanceType13:
    cd_or_prtry: Optional[BalanceType10Choice] = field(
        default=None,
        metadata={
            "name": "CdOrPrtry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    sub_tp: Optional[BalanceSubType1Choice] = field(
        default=None,
        metadata={
            "name": "SubTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class ClearingSystemMemberIdentification2:
    clr_sys_id: Optional[ClearingSystemIdentification2Choice] = field(
        default=None,
        metadata={
            "name": "ClrSysId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    mmb_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class ContactDetails2:
    nm_prfx: Optional[NamePrefix1Code] = field(
        default=None,
        metadata={
            "name": "NmPrfx",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 140,
        },
    )
    phne_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "PhneNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    mob_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "MobNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    fax_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "FaxNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"\+[0-9]{1,3}-[0-9()+\-]{1,30}",
        },
    )
    email_adr: Optional[str] = field(
        default=None,
        metadata={
            "name": "EmailAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 2048,
        },
    )
    othr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericAccountIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 34,
        },
    )
    schme_nm: Optional[AccountSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericFinancialIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[FinancialIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericOrganisationIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[OrganisationIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class GenericPersonIdentification1:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    schme_nm: Optional[PersonIdentificationSchemeName1Choice] = field(
        default=None,
        metadata={
            "name": "SchmeNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    issr: Optional[str] = field(
        default=None,
        metadata={
            "name": "Issr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class Limit2:
    amt: Optional[ActiveOrHistoricCurrencyAndAmount] = field(
        default=None,
        metadata={
            "name": "Amt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    cdt_dbt_ind: Optional[FloorLimitType1Code] = field(
        default=None,
        metadata={
            "name": "CdtDbtInd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )


@dataclass
class PostalAddress6:
    adr_tp: Optional[AddressType2Code] = field(
        default=None,
        metadata={
            "name": "AdrTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "Dept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 70,
        },
    )
    sub_dept: Optional[str] = field(
        default=None,
        metadata={
            "name": "SubDept",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 70,
        },
    )
    strt_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "StrtNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 70,
        },
    )
    bldg_nb: Optional[str] = field(
        default=None,
        metadata={
            "name": "BldgNb",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 16,
        },
    )
    pst_cd: Optional[str] = field(
        default=None,
        metadata={
            "name": "PstCd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 16,
        },
    )
    twn_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "TwnNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry_sub_dvsn: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtrySubDvsn",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    ctry: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ctry",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    adr_line: List[str] = field(
        default_factory=list,
        metadata={
            "name": "AdrLine",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "max_occurs": 7,
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class ReportingPeriod2:
    fr_to_dt: Optional[DatePeriodDetails1] = field(
        default=None,
        metadata={
            "name": "FrToDt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    fr_to_tm: Optional[TimePeriodDetails1] = field(
        default=None,
        metadata={
            "name": "FrToTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    tp: Optional[QueryType3Code] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )


@dataclass
class SequenceRange1Choice:
    fr_seq: Optional[str] = field(
        default=None,
        metadata={
            "name": "FrSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    to_seq: Optional[str] = field(
        default=None,
        metadata={
            "name": "ToSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    fr_to_seq: List[SequenceRange1] = field(
        default_factory=list,
        metadata={
            "name": "FrToSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    eqseq: List[str] = field(
        default_factory=list,
        metadata={
            "name": "EQSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    neqseq: List[str] = field(
        default_factory=list,
        metadata={
            "name": "NEQSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )


@dataclass
class SupplementaryData1:
    plc_and_nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "PlcAndNm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 350,
        },
    )
    envlp: Optional[SupplementaryDataEnvelope1] = field(
        default=None,
        metadata={
            "name": "Envlp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )


@dataclass
class AccountIdentification4Choice:
    iban: Optional[str] = field(
        default=None,
        metadata={
            "name": "IBAN",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"[A-Z]{2,2}[0-9]{2,2}[a-zA-Z0-9]{1,30}",
        },
    )
    othr: Optional[GenericAccountIdentification1] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class BranchData2:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress6] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class FinancialInstitutionIdentification8:
    bicfi: Optional[str] = field(
        default=None,
        metadata={
            "name": "BICFI",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    clr_sys_mmb_id: Optional[ClearingSystemMemberIdentification2] = field(
        default=None,
        metadata={
            "name": "ClrSysMmbId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress6] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    othr: Optional[GenericFinancialIdentification1] = field(
        default=None,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class OrganisationIdentification8:
    any_bic: Optional[str] = field(
        default=None,
        metadata={
            "name": "AnyBIC",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"[A-Z]{6,6}[A-Z2-9][A-NP-Z0-9]([A-Z0-9]{3,3}){0,1}",
        },
    )
    othr: List[GenericOrganisationIdentification1] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class PersonIdentification13:
    dt_and_plc_of_birth: Optional[DateAndPlaceOfBirth1] = field(
        default=None,
        metadata={
            "name": "DtAndPlcOfBirth",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    othr: List[GenericPersonIdentification1] = field(
        default_factory=list,
        metadata={
            "name": "Othr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class TransactionType2:
    sts: Optional[EntryStatus1Choice] = field(
        default=None,
        metadata={
            "name": "Sts",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    cdt_dbt_ind: Optional[CreditDebitCode] = field(
        default=None,
        metadata={
            "name": "CdtDbtInd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    flr_lmt: List[Limit2] = field(
        default_factory=list,
        metadata={
            "name": "FlrLmt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class BranchAndFinancialInstitutionIdentification5:
    fin_instn_id: Optional[FinancialInstitutionIdentification8] = field(
        default=None,
        metadata={
            "name": "FinInstnId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    brnch_id: Optional[BranchData2] = field(
        default=None,
        metadata={
            "name": "BrnchId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class CashAccount24:
    id: Optional[AccountIdentification4Choice] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    tp: Optional[CashAccountType2Choice] = field(
        default=None,
        metadata={
            "name": "Tp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    ccy: Optional[str] = field(
        default=None,
        metadata={
            "name": "Ccy",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"[A-Z]{3,3}",
        },
    )
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 70,
        },
    )


@dataclass
class Party34Choice:
    org_id: Optional[OrganisationIdentification8] = field(
        default=None,
        metadata={
            "name": "OrgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    prvt_id: Optional[PersonIdentification13] = field(
        default=None,
        metadata={
            "name": "PrvtId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class PartyIdentification125:
    nm: Optional[str] = field(
        default=None,
        metadata={
            "name": "Nm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 140,
        },
    )
    pstl_adr: Optional[PostalAddress6] = field(
        default=None,
        metadata={
            "name": "PstlAdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    id: Optional[Party34Choice] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    ctry_of_res: Optional[str] = field(
        default=None,
        metadata={
            "name": "CtryOfRes",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "pattern": r"[A-Z]{2,2}",
        },
    )
    ctct_dtls: Optional[ContactDetails2] = field(
        default=None,
        metadata={
            "name": "CtctDtls",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class Party35Choice:
    pty: Optional[PartyIdentification125] = field(
        default=None,
        metadata={
            "name": "Pty",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    agt: Optional[BranchAndFinancialInstitutionIdentification5] = field(
        default=None,
        metadata={
            "name": "Agt",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class GroupHeader76:
    msg_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "MsgId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    cre_dt_tm: Optional[XmlDateTime] = field(
        default=None,
        metadata={
            "name": "CreDtTm",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    msg_sndr: Optional[Party35Choice] = field(
        default=None,
        metadata={
            "name": "MsgSndr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class ReportingRequest4:
    id: Optional[str] = field(
        default=None,
        metadata={
            "name": "Id",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_length": 1,
            "max_length": 35,
        },
    )
    reqd_msg_nm_id: Optional[str] = field(
        default=None,
        metadata={
            "name": "ReqdMsgNmId",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
            "min_length": 1,
            "max_length": 35,
        },
    )
    acct: Optional[CashAccount24] = field(
        default=None,
        metadata={
            "name": "Acct",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    acct_ownr: Optional[Party35Choice] = field(
        default=None,
        metadata={
            "name": "AcctOwnr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    acct_svcr: Optional[BranchAndFinancialInstitutionIdentification5] = field(
        default=None,
        metadata={
            "name": "AcctSvcr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    rptg_prd: Optional[ReportingPeriod2] = field(
        default=None,
        metadata={
            "name": "RptgPrd",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    rptg_seq: Optional[SequenceRange1Choice] = field(
        default=None,
        metadata={
            "name": "RptgSeq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    reqd_tx_tp: Optional[TransactionType2] = field(
        default=None,
        metadata={
            "name": "ReqdTxTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )
    reqd_bal_tp: List[BalanceType13] = field(
        default_factory=list,
        metadata={
            "name": "ReqdBalTp",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class AccountReportingRequestV04:
    grp_hdr: Optional[GroupHeader76] = field(
        default=None,
        metadata={
            "name": "GrpHdr",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "required": True,
        },
    )
    rptg_req: List[ReportingRequest4] = field(
        default_factory=list,
        metadata={
            "name": "RptgReq",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
            "min_occurs": 1,
        },
    )
    splmtry_data: List[SupplementaryData1] = field(
        default_factory=list,
        metadata={
            "name": "SplmtryData",
            "type": "Element",
            "namespace": "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04",
        },
    )


@dataclass
class Document:
    class Meta:
        namespace = "urn:iso:std:iso:20022:tech:xsd:camt.060.001.04"

    acct_rptg_req: Optional[AccountReportingRequestV04] = field(
        default=None,
        metadata={
            "name": "AcctRptgReq",
            "type": "Element",
            "required": True,
        },
    )



from pyiso20022.camt.camt_060_001_06.camt_060_001_06 import (
    AccountIdentification4Choice,
    AccountReportingRequestV06,
    AccountSchemeName1Choice,
    ActiveOrHistoricCurrencyAndAmount,
    AddressType2Code,
    AddressType3Choice,
    BalanceSubType1Choice,
    BalanceType10Choice,
    BalanceType13,
    BranchAndFinancialInstitutionIdentification6,
    BranchData3,
    CashAccount40,
    CashAccountType2Choice,
    ClearingSystemIdentification2Choice,
    ClearingSystemMemberIdentification2,
    Contact4,
    CreditDebitCode,
    DateAndPlaceOfBirth1,
    DatePeriod3,
    Document,
    EntryStatus1Choice,
    FinancialIdentificationSchemeName1Choice,
    FinancialInstitutionIdentification18,
    FloorLimitType1Code,
    GenericAccountIdentification1,
    GenericFinancialIdentification1,
    GenericIdentification30,
    GenericOrganisationIdentification1,
    GenericPersonIdentification1,
    GroupHeader77,
    Limit2,
    NamePrefix2Code,
    OrganisationIdentification29,
    OrganisationIdentificationSchemeName1Choice,
    OtherContact1,
    Party38Choice,
    Party40Choice,
    PartyIdentification135,
    PersonIdentification13,
    PersonIdentificationSchemeName1Choice,
    PostalAddress24,
    PreferredContactMethod1Code,
    ProxyAccountIdentification1,
    ProxyAccountType1Choice,
    QueryType3Code,
    ReportingPeriod5,
    ReportingRequest6,
    SequenceRange1,
    SequenceRange1Choice,
    SupplementaryData1,
    SupplementaryDataEnvelope1,
    TimePeriodDetails1,
    TransactionType2,
)

__all__ = [
    "AccountIdentification4Choice",
    "AccountReportingRequestV06",
    "AccountSchemeName1Choice",
    "ActiveOrHistoricCurrencyAndAmount",
    "AddressType2Code",
    "AddressType3Choice",
    "BalanceSubType1Choice",
    "BalanceType10Choice",
    "BalanceType13",
    "BranchAndFinancialInstitutionIdentification6",
    "BranchData3",
    "CashAccount40",
    "CashAccountType2Choice",
    "ClearingSystemIdentification2Choice",
    "ClearingSystemMemberIdentification2",
    "Contact4",
    "CreditDebitCode",
    "DateAndPlaceOfBirth1",
    "DatePeriod3",
    "Document",
    "EntryStatus1Choice",
    "FinancialIdentificationSchemeName1Choice",
    "FinancialInstitutionIdentification18",
    "FloorLimitType1Code",
    "GenericAccountIdentification1",
    "GenericFinancialIdentification1",
    "GenericIdentification30",
    "GenericOrganisationIdentification1",
    "GenericPersonIdentification1",
    "GroupHeader77",
    "Limit2",
    "NamePrefix2Code",
    "OrganisationIdentification29",
    "OrganisationIdentificationSchemeName1Choice",
    "OtherContact1",
    "Party38Choice",
    "Party40Choice",
    "PartyIdentification135",
    "PersonIdentification13",
    "PersonIdentificationSchemeName1Choice",
    "PostalAddress24",
    "PreferredContactMethod1Code",
    "ProxyAccountIdentification1",
    "ProxyAccountType1Choice",
    "QueryType3Code",
    "ReportingPeriod5",
    "ReportingRequest6",
    "SequenceRange1",
    "SequenceRange1Choice",
    "SupplementaryData1",
    "SupplementaryDataEnvelope1",
    "TimePeriodDetails1",
    "TransactionType2",
]
